@@ -75,9 +75,11 @@ def setup_continuous_profiler(options, sdk_info, capture_func):
     # type: (Dict[str, Any], SDKInfo, Callable[[Envelope], None]) -> bool
     global _scheduler
 
-    if _scheduler is not None:
+    already_initialized = _scheduler is not None
+
+    if already_initialized:
         logger.debug("[Profiling] Continuous Profiler is already setup")
-        return False
+        teardown_continuous_profiler()
 
     if is_gevent():
         # If gevent has patched the threading modules then we cannot rely on
@@ -117,11 +119,19 @@ def setup_continuous_profiler(options, sdk_info, capture_func):
         )
     )
 
-    atexit.register(teardown_continuous_profiler)
+    if not already_initialized:
+        atexit.register(teardown_continuous_profiler)
 
     return True
 
 
+def is_profile_session_sampled():
+    # type: () -> bool
+    if _scheduler is None:
+        return False
+    return _scheduler.sampled
+
+
 def try_autostart_continuous_profiler():
     # type: () -> None
 
